@@ -1,6 +1,7 @@
 import json
 from logging import log
 from nlp_basictasks.modules.transformers.modeling_bert import BertModel
+from nlp_basictasks.modules.transformers.tokenization_bert import BertTokenizer
 import numpy as np
 import os,sys
 from typing import Dict, Sequence, Text, Type, Callable, List, Optional, Union
@@ -253,6 +254,7 @@ class SimilarityRetrieve(nn.Module):
         '''
         
         '''
+        super(SimilarityRetrieve,self).__init__()
         #logger.info("Bert model path and pooling model path is required")
         self.max_seq_lenth=max_seq_length
         if not os.path.exists(os.path.join(bert_model_path,'pytorch_model.bin')):
@@ -260,9 +262,10 @@ class SimilarityRetrieve(nn.Module):
         else:
             assert os.path.exists(os.path.join(bert_model_path,'config.json'))
             self.bert=BertModel.from_pretrained(bert_model_path)
+            self.tokenizer=BertTokenizer.from_pretrained(bert_model_path)
             pooling_config.update({'word_embedding_dimension':self.bert.config.hidden_size})
         
-        if not os.path.exists(os.path.join(pooling_model_path,'config.json')):
+        if pooling_model_path==None or not os.path.exists(os.path.join(pooling_model_path,'config.json')):
             self.pooling=Pooling(**pooling_config)
         else:
             self.pooling=Pooling.load(pooling_model_path)
@@ -278,6 +281,7 @@ class SimilarityRetrieve(nn.Module):
         if device is None:
             device = "cuda" if torch.cuda.is_available() else "cpu"
             logger.info("Use pytorch device: {}".format(device))
+        self._target_device=device
         self.to(device)
 
     def smart_batching_collate(self,batch):
@@ -311,7 +315,7 @@ class SimilarityRetrieve(nn.Module):
         sentences_sorted = [sentences[idx] for idx in length_sorted_idx]
         for start_index in trange(0, len(sentences), batch_size, desc="Batches", disable=not show_progress_bar):
             sentences_batch = sentences_sorted[start_index:start_index+batch_size]
-            features=convert_sentences_to_features(sentences_batch,tokenizer=self.model.tokenizer)
+            features=convert_sentences_to_features(sentences_batch,tokenizer=self.tokenizer)
             features=batch_to_device(features,device)
             with torch.no_grad():
                 embeddings=self.encoding_feature_to_embedding(sentence_features=features,output_all_encoded_layers=output_all_encoded_layers)
